Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon EventBridge.

Actions, resources, and condition keys for Amazon EventBridge - Service Authorization Reference

# Actions, resources, and condition keys for Amazon EventBridge

Amazon EventBridge (service prefix: `events` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon EventBridge
- Resource types defined by Amazon EventBridge
- Condition keys for Amazon EventBridge

## Actions defined by Amazon EventBridge

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
ActivateEventSource | Grants permission to activate partner event sources | Write | event-source* |  |
CancelReplay | Grants permission to cancel a replay | Write | replay* |  |
CreateApiDestination | Grants permission to create a new api destination | Write | api-destination* |  |
connection* |  |
CreateArchive | Grants permission to create a new archive | Write | archive* |  |
CreateConnection | Grants permission to create a new connection | Write | connection* |  |
CreateEndpoint | Grants permission to create an endpoint | Write | endpoint* |  |
| events:EventBusArn |
CreateEventBus | Grants permission to create event buses | Write | event-bus* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePartnerEventSource | Grants permission to create partner event sources | Write | event-source* |  |
DeactivateEventSource | Grants permission to deactivate event sources | Write | event-source* |  |
DeauthorizeConnection | Grants permission to deauthorize a connection, deleting its stored authorization secrets | Write | connection* |  |
DeleteApiDestination | Grants permission to delete an api destination | Write | api-destination* |  |
DeleteArchive | Grants permission to delete an archive | Write | archive* |  |
DeleteConnection | Grants permission to delete a connection | Write | connection* |  |
DeleteEndpoint | Grants permission to delete an endpoint | Write | endpoint* |  |
DeleteEventBus | Grants permission to delete event buses | Write | event-bus* |  |
DeletePartnerEventSource | Grants permission to delete partner event sources | Write | event-source* |  |
DeleteRule | Grants permission to delete rules | Write | rule* |  |
| events:creatorAccount events:ManagedBy |
DescribeApiDestination | Grants permission to retrieve details about an api destination | Read | api-destination* |  |
connection* |  |
DescribeArchive | Grants permission to retrieve details about an archive | Read | archive* |  |
DescribeConnection | Grants permission to retrieve details about a conection | Read | connection* |  |
DescribeEndpoint | Grants permission to retrieve details about an endpoint | Read | endpoint* |  |
DescribeEventBus | Grants permission to retrieve details about event buses | Read | event-bus |  |
DescribeEventSource | Grants permission to retrieve details about event sources | Read | event-source* |  |
DescribePartnerEventSource | Grants permission to retrieve details about partner event sources | Read | event-source* |  |
DescribeReplay | Grants permission to retrieve the details of a replay | Read | replay* |  |
DescribeRule | Grants permission to retrieve details about rules | Read | rule* |  |
| events:creatorAccount |
DisableRule | Grants permission to disable rules | Write | rule* |  |
| events:creatorAccount events:ManagedBy |
EnableRule | Grants permission to enable rules | Write | rule* |  |
| events:creatorAccount events:ManagedBy |
InvokeApiDestination [permission only] | Grants permission to invoke an api destination | Write | api-destination* |  |
ListApiDestinations | Grants permission to retrieve a list of api destinations | List |  |  |
ListArchives | Grants permission to retrieve a list of archives | List |  |  |
ListConnections | Grants permission to retrieve a list of connections | List |  |  |
ListEndpoints | Grants permission to retrieve a list of endpoints | List |  |  |
ListEventBuses | Grants permission to retrieve a list of the event buses in your account | List |  |  |
ListEventSources | Grants permission to to retrieve a list of event sources shared with this account | List |  |  |
ListPartnerEventSourceAccounts | Grants permission to retrieve a list of AWS account IDs associated with an event source | List | event-source* |  |
ListPartnerEventSources | Grants permission to retrieve a list partner event sources | List |  |  |
ListReplays | Grants permission to retrieve a list of replays | List |  |  |
ListRuleNamesByTarget | Grants permission to retrieve a list of the names of the rules associated with a target | List |  |  |
ListRules | Grants permission to retrieve a list of the Amazon EventBridge rules in the account | List |  |  |
ListTagsForResource | Grants permission to retrieve a list of tags associated with an Amazon EventBridge resource | List | event-bus |  |
rule |  |
| events:creatorAccount |
ListTargetsByRule | Grants permission to retrieve a list of targets defined for a rule | List | rule* |  |
| events:creatorAccount |
PutEvents | Grants permission to send custom events to Amazon EventBridge | Write | event-bus* |  |
| events:detail-type events:source events:eventBusInvocation |
PutPartnerEvents | Grants permission to sends custom events to Amazon EventBridge | Write |  |  |
PutPermission | Grants permission to use the PutPermission action to grants permission to another AWS account to put events to your default event bus | Permissions management |  |  |
PutRule | Grants permission to create or updates rules | Write | rule* |  |
| events:detail.userIdentity.principalId events:detail-type events:source events:detail.service events:detail.eventTypeCode aws:RequestTag/${TagKey} aws:TagKeys events:creatorAccount events:ManagedBy |
PutTargets | Grants permission to add targets to a rule | Write | rule* |  |
| events:TargetArn events:creatorAccount events:ManagedBy |
RemovePermission | Grants permission to revoke the permission of another AWS account to put events to your default event bus | Permissions management |  |  |
RemoveTargets | Grants permission to removes targets from a rule | Write | rule* |  |
| events:creatorAccount events:ManagedBy |
StartReplay | Grants permission to start a replay of an archive | Write | archive* |  |
TagResource | Grants permission to add a tag to an Amazon EventBridge resource | Tagging | event-bus |  |
rule |  |
| aws:TagKeys aws:RequestTag/${TagKey} events:creatorAccount |
TestEventPattern | Grants permission to test whether an event pattern matches the provided event | Read |  |  |
UntagResource | Grants permission to remove a tag from an Amazon EventBridge resource | Tagging | event-bus |  |
rule |  |
| aws:TagKeys events:creatorAccount |
UpdateApiDestination | Grants permission to update an api destination | Write | api-destination* |  |
UpdateArchive | Grants permission to update an archive | Write | archive* |  |
UpdateConnection | Grants permission to update a connection | Write | connection* |  |
UpdateEndpoint | Grants permission to update an endpoint | Write | endpoint* |  |
| events:EventBusArn |

## Resource types defined by Amazon EventBridge

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
event-source | `arn:$ { Partition}:events:$ { Region}::event-source/$ { EventSourceName}` |
event-bus | `arn:$ { Partition}:events:$ { Region}:$ { Account}:event-bus/$ { EventBusName}` | aws:ResourceTag/${TagKey}
rule | `arn:$ { Partition}:events:$ { Region}:$ { Account}:rule/[$ { EventBusName}/]$ { RuleName}` | aws:ResourceTag/${TagKey}
archive | `arn:$ { Partition}:events:$ { Region}:$ { Account}:archive/$ { ArchiveName}` |
replay | `arn:$ { Partition}:events:$ { Region}:$ { Account}:replay/$ { ReplayName}` |
connection | `arn:$ { Partition}:events:$ { Region}:$ { Account}:connection/$ { ConnectionName}` |
api-destination | `arn:$ { Partition}:events:$ { Region}:$ { Account}:api-destination/$ { ApiDestinationName}` |
endpoint | `arn:$ { Partition}:events:$ { Region}:$ { Account}:endpoint/$ { EndpointName}` |

## Condition keys for Amazon EventBridge

Amazon EventBridge defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the allowed set of values for each of the tags to event bus and rule actions | String
aws:ResourceTag/${TagKey} | Filters access by tag-value associated with the resource to event bus and rule actions | String
aws:TagKeys | Filters access by the tags in the request to event bus and rule actions | ArrayOfString
events:EventBusArn | Filters access by the ARN of the event buses that can be associated with an endpoint to CreateEndpoint and UpdateEndpoint actions | ArrayOfARN
events:ManagedBy | Filters access by AWS services. If a rule is created by an AWS service on your behalf, the value is the principal name of the service that created the rule | String
events:TargetArn | Filters access by the ARN of a target that can be put to a rule to PutTargets actions | ArrayOfARN
events:creatorAccount | Filters access by the account the rule was created in to rule actions | String
events:detail-type | Filters access by the literal string of the detail-type of the event to PutEvents and PutRule actions | String
events:detail.eventTypeCode | Filters access by the literal string for the detail.eventTypeCode field of the event to PutRule actions | String
events:detail.service | Filters access by the literal string for the detail.service field of the event to PutRule actions | String
events:detail.userIdentity.principalId | Filters access by the literal string for the detail.useridentity.principalid field of the event to PutRule actions | String
events:eventBusInvocation | Filters access by whether the event was generated via API or cross-account bus invocation to PutEvents actions | String
events:source | Filters access by the AWS service or AWS partner event source that generated the event to PutEvents and PutRule actions. Matches the literal string of the source field of the event | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.